smartcard.pyro.server.PyroNameServer.PyroNameServer

# ``smartcard`.`pyro`.`server`.`PyroNameServer`.`PyroNameServer``

class documentation

`class PyroNameServer(Thread):`

View In Hierarchy

Thread running the Pyro Name server.

Method | `__call__` | Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal
Method | `__init__` | Initialize pyro name server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-ns start script.
Method | `getShutdownArgs` | return command line arguments for shutting down the server; this command line is built from the name server startup arguments.
Method | `listall` | List pyro namespace.
Method | `ping` | Ping pyro naming server.
Method | `run` | Starts Pyro naming server with command line arguments (see pyro documentation)
Method | `stop` | Shutdown pyro naming server.
Method | `waitStarted` | wait until name server is started.
Instance Variable | `args` | Undocumented
Instance Variable | `bcaddr` | Undocumented
Instance Variable | `bcport` | Undocumented
Instance Variable | `handler` | Undocumented
Instance Variable | `host` | Undocumented
Instance Variable | `identification` | Undocumented

def __call__(self, signame, sf):

Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal

def __init__(self, args=[]):

Initialize pyro name server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-ns start script.

def getShutdownArgs(self):

return command line arguments for shutting down the server; this command line is built from the name server startup arguments.

def listall(self):

List pyro namespace.

def ping(self):

Ping pyro naming server.

def run(self):

Starts Pyro naming server with command line arguments (see pyro documentation)

def stop(self):

Shutdown pyro naming server.

def waitStarted(self):

wait until name server is started.

args =

Undocumented

bcaddr =

Undocumented

bcport =

Undocumented

handler =

Undocumented

host =

Undocumented

identification =

Undocumented